@@ -4,5 +4,11 @@
 SPEC-First TDD Framework with Alfred SuperAgent
 """
 
-__version__ = "0.3.3"
+from importlib.metadata import PackageNotFoundError, version
+
+try:
+    __version__ = version("moai-adk")
+except PackageNotFoundError:
+    __version__ = "0.4.1-dev"
+
 __all__ = ["__version__"]
