@@ -1,8 +1,9 @@
-# @CODE:TEMPLATE-001 | SPEC: SPEC-INIT-003.md | Chain: TEMPLATE-001
+# @CODE:TEMPLATE-001 | SPEC: SPEC-INIT-003/spec.md | Chain: TEMPLATE-001
 """Template copy and backup processor (SPEC-INIT-003 v0.3.0: preserve user content)."""
 
 from __future__ import annotations
 
+import re
 import shutil
 from pathlib import Path
 
@@ -22,7 +23,8 @@ class TemplateProcessor:
         ".moai/specs/",  # User SPEC documents
         ".moai/reports/",  # User reports
         ".moai/project/",  # User project documents (product/structure/tech.md)
-        ".moai/config.json",  # User configuration (merged via /alfred:9-update flow)
+        # config.json is now FORCE OVERWRITTEN (backup in .moai-backups/)
+        # Merge via /alfred:0-project when optimized=false
     ]
 
     # Paths excluded from backups
@@ -38,6 +40,7 @@ class TemplateProcessor:
         self.template_root = self._get_template_root()
         self.backup = TemplateBackup(self.target_path)
         self.merger = TemplateMerger(self.target_path)
+        self.context: dict[str, str] = {}  # Template variable substitution context
 
     def _get_template_root(self) -> Path:
         """Return the template root path."""
@@ -46,6 +49,116 @@ class TemplateProcessor:
         package_root = current_file.parent.parent.parent
         return package_root / "templates"
 
+    def set_context(self, context: dict[str, str]) -> None:
+        """Set variable substitution context.
+
+        Args:
+            context: Dictionary of template variables.
+        """
+        self.context = context
+
+    def _substitute_variables(self, content: str) -> tuple[str, list[str]]:
+        """Substitute template variables in content.
+
+        Returns:
+            Tuple of (substituted_content, warnings_list)
+        """
+        warnings = []
+
+        # Perform variable substitution
+        for key, value in self.context.items():
+            placeholder = f"{{{{{key}}}}}"  # {{KEY}}
+            if placeholder in content:
+                safe_value = self._sanitize_value(value)
+                content = content.replace(placeholder, safe_value)
+
+        # Detect unsubstituted variables
+        remaining = re.findall(r'\{\{([A-Z_]+)\}\}', content)
+        if remaining:
+            unique_remaining = sorted(set(remaining))
+            warnings.append(f"Unsubstituted variables: {', '.join(unique_remaining)}")
+
+        return content, warnings
+
+    def _sanitize_value(self, value: str) -> str:
+        """Sanitize value to prevent recursive substitution and control characters.
+
+        Args:
+            value: Value to sanitize.
+
+        Returns:
+            Sanitized value.
+        """
+        # Remove control characters (keep printable and whitespace)
+        value = ''.join(c for c in value if c.isprintable() or c in '\n\r\t')
+        # Prevent recursive substitution by removing placeholder patterns
+        value = value.replace('{{', '').replace('}}', '')
+        return value
+
+    def _is_text_file(self, file_path: Path) -> bool:
+        """Check if file is text-based (not binary).
+
+        Args:
+            file_path: File path to check.
+
+        Returns:
+            True if file is text-based.
+        """
+        text_extensions = {
+            '.md', '.json', '.txt', '.py', '.ts', '.js',
+            '.yaml', '.yml', '.toml', '.xml', '.sh', '.bash'
+        }
+        return file_path.suffix.lower() in text_extensions
+
+    def _copy_file_with_substitution(self, src: Path, dst: Path) -> list[str]:
+        """Copy file with variable substitution for text files.
+
+        Args:
+            src: Source file path.
+            dst: Destination file path.
+
+        Returns:
+            List of warnings.
+        """
+        warnings = []
+
+        # Text files: read, substitute, write
+        if self._is_text_file(src) and self.context:
+            try:
+                content = src.read_text(encoding='utf-8')
+                content, file_warnings = self._substitute_variables(content)
+                dst.write_text(content, encoding='utf-8')
+                warnings.extend(file_warnings)
+            except UnicodeDecodeError:
+                # Binary file fallback
+                shutil.copy2(src, dst)
+        else:
+            # Binary file or no context: simple copy
+            shutil.copy2(src, dst)
+
+        return warnings
+
+    def _copy_dir_with_substitution(self, src: Path, dst: Path) -> None:
+        """Recursively copy directory with variable substitution for text files.
+
+        Args:
+            src: Source directory path.
+            dst: Destination directory path.
+        """
+        dst.mkdir(parents=True, exist_ok=True)
+
+        for item in src.rglob("*"):
+            rel_path = item.relative_to(src)
+            dst_item = dst / rel_path
+
+            if item.is_file():
+                # Create parent directory if needed
+                dst_item.parent.mkdir(parents=True, exist_ok=True)
+                # Copy with variable substitution
+                self._copy_file_with_substitution(item, dst_item)
+            elif item.is_dir():
+                dst_item.mkdir(parents=True, exist_ok=True)
+
     def copy_templates(self, backup: bool = True, silent: bool = False) -> None:
         """Copy template files into the project.
 
@@ -65,6 +178,7 @@ class TemplateProcessor:
 
         self._copy_claude(silent)
         self._copy_moai(silent)
+        self._copy_github(silent)
         self._copy_claude_md(silent)
         self._copy_gitignore(silent)
 
@@ -115,11 +229,16 @@ class TemplateProcessor:
                 dst_item.mkdir(parents=True, exist_ok=True)
 
     def _copy_claude(self, silent: bool = False) -> None:
-        """.claude/ directory copy (selective with alfred folder overwrite).
+        """.claude/ directory copy with variable substitution (selective with alfred folder overwrite).
+
+        @CODE:INIT-004:ALFRED-001 | Copy all 4 Alfred command files from templates
+        @REQ:COMMAND-GENERATION-001 | SPEC-INIT-004: Automatic generation of Alfred command files
+        @SPEC:TEMPLATE-PROCESSING-001 | Template processor integration for Alfred command files
 
         Strategy:
         - Alfred folders (commands/agents/hooks/output-styles/alfred) → copy wholesale (delete & overwrite)
           * Creates individual backup before deletion for safety
+          * Commands: 0-project.md, 1-plan.md, 2-run.md, 3-sync.md
         - Other files/folders → copy individually (preserve existing)
         """
         src = self.template_root / ".claude"
@@ -133,10 +252,12 @@ class TemplateProcessor:
         # Create .claude directory if not exists
         dst.mkdir(parents=True, exist_ok=True)
 
+        # @CODE:INIT-004:ALFRED-002 | Alfred command files must always be overwritten
+        # @CODE:INIT-004:ALFRED-COPY | Copy all 4 Alfred command files from templates
         # Alfred folders to copy wholesale (overwrite)
         alfred_folders = [
             "hooks/alfred",
-            "commands/alfred",
+            "commands/alfred",  # Contains 0-project.md, 1-plan.md, 2-run.md, 3-sync.md
             "output-styles/alfred",
             "agents/alfred",
         ]
@@ -147,9 +268,8 @@ class TemplateProcessor:
             dst_folder = dst / folder
 
             if src_folder.exists():
-                # Backup this folder before deletion (safety measure)
+                # Remove existing folder (backup is already handled by create_backup() in update.py)
                 if dst_folder.exists():
-                    self._backup_alfred_folder(dst_folder, folder)
                     shutil.rmtree(dst_folder)
 
                 # Create parent directory if needed
@@ -158,7 +278,8 @@ class TemplateProcessor:
                 if not silent:
                     console.print(f"   ✅ .claude/{folder}/ overwritten")
 
-        # 2. Copy other files/folders individually (preserve existing)
+        # 2. Copy other files/folders individually (smart merge for settings.json)
+        all_warnings = []
         for item in src.iterdir():
             rel_path = item.relative_to(src)
             dst_item = dst / rel_path
@@ -168,44 +289,30 @@ class TemplateProcessor:
                 continue
 
             if item.is_file():
-                # Copy file, skip if exists (preserve user modifications)
-                if not dst_item.exists():
-                    shutil.copy2(item, dst_item)
+                # Smart merge for settings.json
+                if item.name == "settings.json":
+                    self._merge_settings_json(item, dst_item)
+                    if not silent:
+                        console.print("   🔄 settings.json merged (env variables preserved)")
+                else:
+                    # FORCE OVERWRITE: Always copy other files (no skip)
+                    warnings = self._copy_file_with_substitution(item, dst_item)
+                    all_warnings.extend(warnings)
             elif item.is_dir():
-                # Copy directory recursively (preserve existing files)
-                if not dst_item.exists():
-                    shutil.copytree(item, dst_item)
+                # FORCE OVERWRITE: Always copy directories (no skip)
+                self._copy_dir_with_substitution(item, dst_item)
+
+        # Print warnings if any
+        if all_warnings and not silent:
+            console.print("[yellow]⚠️ Template warnings:[/yellow]")
+            for warning in set(all_warnings):  # Deduplicate
+                console.print(f"   {warning}")
 
         if not silent:
-            console.print("   ✅ .claude/ copy complete (alfred folders overwritten, others preserved)")
-
-    def _backup_alfred_folder(self, folder_path: Path, folder_name: str) -> None:
-        """Backup an Alfred folder before overwriting (safety measure).
-
-        Args:
-            folder_path: Path to the folder to backup.
-            folder_name: Name of the folder (e.g., "hooks/alfred").
-        """
-        if not folder_path.exists():
-            return
-
-        # Create backup directory in .moai-backups/.claude-backups/{timestamp}/
-        backup_base = self.target_path / ".moai-backups" / ".claude-backups"
-        backup_base.mkdir(parents=True, exist_ok=True)
-
-        # Generate timestamp-based backup directory
-        from moai_adk.core.project.backup_utils import generate_backup_dir_name
-
-        timestamp = generate_backup_dir_name()
-        backup_dir = backup_base / timestamp
-
-        # Backup this specific folder
-        backup_folder = backup_dir / folder_name
-        backup_folder.parent.mkdir(parents=True, exist_ok=True)
-        shutil.copytree(folder_path, backup_folder)
+            console.print("   ✅ .claude/ copy complete (variables substituted)")
 
     def _copy_moai(self, silent: bool = False) -> None:
-        """.moai/ directory copy (excludes protected paths)."""
+        """.moai/ directory copy with variable substitution (excludes protected paths)."""
         src = self.template_root / ".moai"
         dst = self.target_path / ".moai"
 
@@ -220,6 +327,8 @@ class TemplateProcessor:
             "reports",
         ]
 
+        all_warnings = []
+
         # Copy while skipping protected paths
         for item in src.rglob("*"):
             rel_path = item.relative_to(src)
@@ -231,19 +340,43 @@ class TemplateProcessor:
 
             dst_item = dst / rel_path
             if item.is_file():
-                # Skip existing files to preserve user content (v0.3.0)
-                if dst_item.exists():
-                    continue
+                # FORCE OVERWRITE: Always copy files (no skip)
                 dst_item.parent.mkdir(parents=True, exist_ok=True)
-                shutil.copy2(item, dst_item)
+                # Copy with variable substitution
+                warnings = self._copy_file_with_substitution(item, dst_item)
+                all_warnings.extend(warnings)
             elif item.is_dir():
                 dst_item.mkdir(parents=True, exist_ok=True)
 
+        # Print warnings if any
+        if all_warnings and not silent:
+            console.print("[yellow]⚠️ Template warnings:[/yellow]")
+            for warning in set(all_warnings):  # Deduplicate
+                console.print(f"   {warning}")
+
         if not silent:
-            console.print("   ✅ .moai/ copy complete (user content preserved)")
+            console.print("   ✅ .moai/ copy complete (variables substituted)")
+
+    def _copy_github(self, silent: bool = False) -> None:
+        """.github/ directory copy with variable substitution."""
+        src = self.template_root / ".github"
+        dst = self.target_path / ".github"
+
+        if not src.exists():
+            if not silent:
+                console.print("⚠️ .github/ template not found")
+            return
+
+        if dst.exists():
+            shutil.rmtree(dst)
+
+        self._copy_dir_with_substitution(src, dst)
+
+        if not silent:
+            console.print("   ✅ .github/ copy complete (variables substituted)")
 
     def _copy_claude_md(self, silent: bool = False) -> None:
-        """Copy CLAUDE.md with smart merging."""
+        """Copy CLAUDE.md with smart merge (preserves \"## Project Information\" section)."""
         src = self.template_root / "CLAUDE.md"
         dst = self.target_path / "CLAUDE.md"
 
@@ -252,15 +385,16 @@ class TemplateProcessor:
                 console.print("⚠️ CLAUDE.md template not found")
             return
 
-        # Preserve project information when the file exists
+        # Smart merge: preserve existing "## Project Information" section
         if dst.exists():
             self._merge_claude_md(src, dst)
             if not silent:
                 console.print("   🔄 CLAUDE.md merged (project information preserved)")
         else:
-            shutil.copy2(src, dst)
+            # First time: just copy
+            self._copy_file_with_substitution(src, dst)
             if not silent:
-                console.print("   ✅ CLAUDE.md copy complete")
+                console.print("   ✅ CLAUDE.md created")
 
     def _merge_claude_md(self, src: Path, dst: Path) -> None:
         """Delegate the smart merge for CLAUDE.md.
@@ -271,6 +405,24 @@ class TemplateProcessor:
         """
         self.merger.merge_claude_md(src, dst)
 
+    def _merge_settings_json(self, src: Path, dst: Path) -> None:
+        """Delegate the smart merge for settings.json.
+
+        Args:
+            src: Template settings.json.
+            dst: Project settings.json.
+        """
+        # Find the latest backup for user settings extraction
+        backup_path = None
+        if self.backup.backup_dir.exists():
+            backups = sorted(self.backup.backup_dir.iterdir(), reverse=True)
+            if backups:
+                backup_settings = backups[0] / ".claude" / "settings.json"
+                if backup_settings.exists():
+                    backup_path = backup_settings
+
+        self.merger.merge_settings_json(src, dst, backup_path)
+
     def _copy_gitignore(self, silent: bool = False) -> None:
         """.gitignore copy (optional)."""
         src = self.template_root / ".gitignore"
